@@ -4,63 +4,53 @@ from __future__ import print_function
 
 import datetime
 import threading
-import xmlrpclib
-from SimpleXMLRPCServer import SimpleXMLRPCServer
+import xmlrpc.client as xmlclient
 from xml.sax.saxutils import escape
+from xmlrpc.server import SimpleXMLRPCServer
 
 import idaapi
-import idautils
 import idc
 
 # Wait for any processing to get done
-idaapi.autoWait()
+idaapi.auto_wait()
 
 # On Windows with NTFS filesystem a filepath with ':'
 # is treated as NTFS ADS (Alternative Data Stream)
 # and so saving file with such name fails
-dt = datetime.datetime.now().isoformat().replace(':', '-')
+dt = datetime.datetime.now().isoformat().replace(":", "-")
 
 # Save the database so nothing gets lost.
-if idaapi.IDA_SDK_VERSION >= 700:
-    idaapi.save_database(idc.GetIdbPath() + '.' + dt)
-else:
-    idc.SaveBase(idc.GetIdbPath() + '.' + dt)
+idc.save_database(idc.get_idb_path() + "." + dt)
 
 
 DEBUG_MARSHALLING = False
 
+
 def create_marshaller(use_format=None, just_to_str=False):
-    assert use_format or just_to_str, 'Either pass format to use or make it converting the value to str.'
+    assert (
+        use_format or just_to_str
+    ), "Either pass format to use or make it converting the value to str."
 
     def wrapper(_marshaller, value, appender):
         if use_format:
             marshalled = use_format % value
         elif just_to_str:
-            marshalled = '<value><string>%s</string></value>' % escape(str(value))
+            marshalled = f"<value><string>{escape(str(value))}</string></value>"
 
         if DEBUG_MARSHALLING:
-            print("Marshalled: '%s'" % marshalled)
+            print(f"Marshalled: '{marshalled}'")
 
         appender(marshalled)
 
     return wrapper
 
-xmlrpclib.Marshaller.dispatch[type(0)] = create_marshaller("<value><i8>%d</i8></value>")
-xmlrpclib.Marshaller.dispatch[idaapi.cfuncptr_t] = create_marshaller(just_to_str=True)
 
-host = '127.0.0.1'
+xmlclient.Marshaller.dispatch[type(1 << 63)] = create_marshaller("<value><i8>%d</i8></value>")
+xmlclient.Marshaller.dispatch[type(0)] = create_marshaller("<value><i8>%d</i8></value>")
+xmlclient.Marshaller.dispatch[idaapi.cfuncptr_t] = create_marshaller(just_to_str=True)
+
+host = "127.0.0.1"
 port = 31337
-orig_LineA = idc.LineA
-
-
-def LineA(*a, **kw):
-    v = orig_LineA(*a, **kw)
-    if v and v.startswith('\x01\x04; '):
-        v = v[4:]
-    return v
-
-
-idc.LineA = LineA
 
 mutex = threading.Condition()
 
@@ -79,15 +69,14 @@ def wrap(f):
 
         with mutex:
             flags = idaapi.MFF_WRITE
-            if f == idc.SetColor:
+            if f == idc.set_color:
                 flags |= idaapi.MFF_NOWAIT
                 rv.append(None)
             idaapi.execute_sync(work, flags)
 
         if error:
-            msg = 'Failed on calling {}.{} with args: {}, kwargs: {}\nException: {}' \
-                .format(f.__module__, f.__name__, a, kw, str(error[0]))
-            print('[!!!] ERROR:', msg)
+            msg = f"Failed on calling {f.__module__}.{f.__name__} with args: {a}, kwargs: {kw}\nException: {str(error[0])}"
+            print("[!!!] ERROR:", msg)
             raise error[0]
 
         return rv[0]
@@ -97,7 +86,7 @@ def wrap(f):
 
 def register_module(module):
     for name, function in module.__dict__.items():
-        if hasattr(function, '__call__'):
+        if hasattr(function, "__call__"):
             server.register_function(wrap(function), name)
 
 
@@ -113,6 +102,7 @@ def decompile(addr):
     except idaapi.DecompilationFailure:
         return None
 
+
 def get_decompile_coord_by_ea(cfunc, addr):
     if idaapi.IDA_SDK_VERSION >= 720:
         item = cfunc.body.find_closest_addr(addr)
@@ -130,9 +120,9 @@ def get_decompile_coord_by_ea(cfunc, addr):
             if ret and pitem.it:
                 lnmap[pitem.it.ea] = i
         y = None
-        closest_ea = BADADDR
-        for ea,line in lnmap.items():
-            if closest_ea == BADADDR or abs(closest_ea - addr) > abs(ea - addr):
+        closest_ea = idaapi.BADADDR
+        for ea, line in lnmap.items():
+            if closest_ea == idaapi.BADADDR or abs(closest_ea - addr) > abs(ea - addr):
                 closest_ea = ea
                 y = lnmap[ea]
 
@@ -151,32 +141,35 @@ def decompile_context(addr, context_lines):
     for lnnum in range(max(0, y - context_lines), min(len(lines), y + context_lines)):
         retlines.append(idaapi.tag_remove(lines[lnnum].line))
         if lnnum == y:
-            retlines[-1] = '>' + retlines[-1][1:]
-    return '\n'.join(retlines)
+            retlines[-1] = ">" + retlines[-1][1:]
+    return "\n".join(retlines)
 
 
 def versions():
     """Returns IDA & Python versions"""
     import sys
+
     return {
-        'python': sys.version,
-        'ida': idaapi.get_kernel_version(),
-        'hexrays': idaapi.get_hexrays_version() if idaapi.init_hexrays_plugin() else None
+        "python": sys.version,
+        "ida": idaapi.get_kernel_version(),
+        "hexrays": idaapi.get_hexrays_version() if idaapi.init_hexrays_plugin() else None,
     }
 
 
-server = SimpleXMLRPCServer((host, port), logRequests=True, allow_none=True)
-register_module(idc)
-register_module(idautils)
+server = SimpleXMLRPCServer((host, port), logRequests=False, allow_none=True)
 register_module(idaapi)
-server.register_function(lambda a: eval(a, globals(), locals()), 'eval')
-server.register_function(wrap(decompile)) # overwrites idaapi/ida_hexrays.decompile
-server.register_function(wrap(decompile_context), 'decompile_context')  # support context decompile
-server.register_function(versions)
+register_module(
+    idc
+)  # prioritize idc functions over above (e.g. idc.get_next_seg/ida_segment.get_next_seg)
+
+server.register_function(lambda a: eval(a, globals(), locals()), "eval")
+server.register_function(wrap(decompile))  # overwrites idaapi/ida_hexrays.decompile
+server.register_function(wrap(decompile_context), "decompile_context")  # support context decompile
+server.register_function(wrap(versions))
 server.register_introspection_functions()
 
-print('IDA Pro xmlrpc hosted on http://%s:%s' % (host, port))
-print('Call `shutdown()` to shutdown the IDA Pro xmlrpc server.')
+print(f"IDA Pro xmlrpc hosted on http://{host}:{port}")
+print("Call `shutdown()` to shutdown the IDA Pro xmlrpc server.")
 
 thread = threading.Thread(target=server.serve_forever)
 thread.daemon = True
