@@ -1,18 +1,40 @@
 import gdb
 
-import pwndbg.abi
-import pwndbg.color.chain as C
 import pwndbg.color.memory as M
-import pwndbg.color.theme as theme
 import pwndbg.enhance
-import pwndbg.memory
-import pwndbg.symbol
-import pwndbg.typeinfo
-import pwndbg.vmmap
+import pwndbg.gdblib.abi
+import pwndbg.gdblib.memory
+import pwndbg.gdblib.symbol
+import pwndbg.gdblib.typeinfo
+import pwndbg.gdblib.vmmap
+from pwndbg.color import ColorConfig
+from pwndbg.color import ColorParamSpec
+from pwndbg.color import theme
 
-LIMIT = pwndbg.config.Parameter('dereference-limit', 5, 'max number of pointers to dereference in a chain')
+LIMIT = pwndbg.gdblib.config.add_param(
+    "dereference-limit", 5, "max number of pointers to dereference in a chain"
+)
 
-def get(address, limit=LIMIT, offset=0, hard_stop=None, hard_end=0, include_start=True, safe_linking=False):
+c = ColorConfig(
+    "chain",
+    [
+        ColorParamSpec("arrow", "normal", "color of chain formatting (arrow)"),
+        ColorParamSpec(
+            "contiguous-marker", "normal", "color of chain formatting (contiguous marker)"
+        ),
+    ],
+)
+
+
+def get(
+    address,
+    limit=LIMIT,
+    offset=0,
+    hard_stop=None,
+    hard_end=0,
+    include_start=True,
+    safe_linking=False,
+):
     """
     Recursively dereferences an address. For bare metal, it will stop when the address is not in any of vmmap pages to avoid redundant dereference.
 
@@ -45,12 +67,12 @@ def get(address, limit=LIMIT, offset=0, hard_stop=None, hard_end=0, include_star
 
             # Avoid redundant dereferences in bare metal mode by checking
             # if address is in any of vmmap pages
-            if not pwndbg.abi.linux and not pwndbg.vmmap.find(address):
+            if not pwndbg.gdblib.abi.linux and not pwndbg.gdblib.vmmap.find(address):
                 break
 
-            next_address = int(pwndbg.memory.poi(pwndbg.typeinfo.ppvoid, address))
+            next_address = int(pwndbg.gdblib.memory.poi(pwndbg.gdblib.typeinfo.ppvoid, address))
             address = next_address ^ ((address >> 12) if safe_linking else 0)
-            address &= pwndbg.arch.ptrmask
+            address &= pwndbg.gdblib.arch.ptrmask
             result.append(address)
         except gdb.MemoryError:
             break
@@ -58,9 +80,12 @@ def get(address, limit=LIMIT, offset=0, hard_stop=None, hard_end=0, include_star
     return result
 
 
-config_arrow_left  = theme.Parameter('chain-arrow-left', '◂—', 'left arrow of chain formatting')
-config_arrow_right = theme.Parameter('chain-arrow-right', '—▸', 'right arrow of chain formatting')
-config_contiguous  = theme.Parameter('chain-contiguous-marker', '...', 'contiguous marker of chain formatting')
+config_arrow_left = theme.add_param("chain-arrow-left", "◂—", "left arrow of chain formatting")
+config_arrow_right = theme.add_param("chain-arrow-right", "—▸", "right arrow of chain formatting")
+config_contiguous = theme.add_param(
+    "chain-contiguous-marker", "...", "contiguous marker of chain formatting"
+)
+
 
 def format(value, limit=LIMIT, code=True, offset=0, hard_stop=None, hard_end=0, safe_linking=False):
     """
@@ -88,15 +113,15 @@ def format(value, limit=LIMIT, code=True, offset=0, hard_stop=None, hard_end=0,
     else:
         chain = get(value, limit, offset, hard_stop, hard_end, safe_linking=safe_linking)
 
-    arrow_left  = C.arrow(' %s ' % config_arrow_left)
-    arrow_right = C.arrow(' %s ' % config_arrow_right)
+    arrow_left = c.arrow(f" {config_arrow_left} ")
+    arrow_right = c.arrow(f" {config_arrow_right} ")
 
     # Colorize the chain
     rest = []
     for link in chain:
-        symbol = pwndbg.symbol.get(link) or None
+        symbol = pwndbg.gdblib.symbol.get(link) or None
         if symbol:
-            symbol = '%#x (%s)' % (link, symbol)
+            symbol = "%#x (%s)" % (link, symbol)
         rest.append(M.get(link, symbol))
 
     # If the dereference limit is zero, skip any enhancements.
@@ -118,7 +143,7 @@ def format(value, limit=LIMIT, code=True, offset=0, hard_stop=None, hard_end=0,
         enhanced = pwndbg.enhance.enhance(chain[-2] + offset, code=code, safe_linking=safe_linking)
 
     else:
-        enhanced = C.contiguous('%s' % config_contiguous)
+        enhanced = c.contiguous_marker(f"{config_contiguous}")
 
     if len(chain) == 1:
         return enhanced
