@@ -30,7 +30,7 @@ parser.add_argument(
 @pwndbg.commands.ArgparsedCommand(parser, category=CommandCategory.LINUX)
 def aslr(state=None) -> None:
     if state:
-        gdb.execute("set disable-randomization %s" % options[state], from_tty=False, to_string=True)
+        gdb.execute(f"set disable-randomization {options[state]}", from_tty=False, to_string=True)
 
         if pwndbg.gdblib.proc.alive:
             print("Change will take effect when the process restarts")
@@ -44,4 +44,4 @@ def aslr(state=None) -> None:
     else:
         status = message.off("???")
 
-    print("ASLR is %s (%s)" % (status, method))
+    print(f"ASLR is {status} ({method})")
