@@ -16,10 +16,10 @@ Useful for diagnosing caching-related bugs. Decreases performance.
 
 @pwndbg.commands.ArgparsedCommand(parser, category=CommandCategory.PWNDBG)
 def memoize() -> None:
-    pwndbg.lib.memoize.memoize.caching = not pwndbg.lib.memoize.memoize.caching
+    pwndbg.lib.cache.IS_CACHING = not pwndbg.lib.cache.IS_CACHING
 
     status = message.off("OFF (pwndbg will work slower, use only for debugging pwndbg)")
-    if pwndbg.lib.memoize.memoize.caching:
+    if pwndbg.lib.cache.IS_CACHING:
         status = message.on("ON")
 
-    print("Caching is now %s" % status)
+    print(f"Caching is now {status}")
