@@ -23,11 +23,10 @@ parser.add_argument("argument", nargs="*", type=str, help="Arguments to pass to
 @pwndbg.commands.OnlyWithFile
 def rop(grep, argument) -> None:
     with tempfile.NamedTemporaryFile() as corefile:
-
         # If the process is running, dump a corefile so we get actual addresses.
         if pwndbg.gdblib.proc.alive:
             filename = corefile.name
-            gdb.execute("gcore %s" % filename)
+            gdb.execute(f"gcore {filename}")
         else:
             filename = pwndbg.gdblib.proc.exe
 
