@@ -4,7 +4,7 @@ import traceback
 
 import gdb
 
-import pwndbg.lib.memoize
+import pwndbg.lib.cache
 import pwndbg.lib.stdio
 from pwndbg.color import message
 from pwndbg.gdblib import config
@@ -13,7 +13,7 @@ with pwndbg.lib.stdio.stdio:
     try:
         import ipdb as pdb
     except ImportError:
-        import pdb  # type: ignore
+        import pdb
     try:
         from rich.console import Console
 
@@ -31,11 +31,11 @@ debug = config.add_param(
 )
 
 
-@pwndbg.lib.memoize.forever
+@pwndbg.lib.cache.cache_until("forever")
 def inform_report_issue(exception_msg) -> None:
     """
     Informs user that he can report an issue.
-    The use of `memoize` makes it reporting only once for a given exception message.
+    The use of caching makes it reporting only once for a given exception message.
     """
     print(
         message.notice(
@@ -86,7 +86,7 @@ def handle(name="Error"):
     else:
         exc_type, exc_value, exc_traceback = sys.exc_info()
 
-        print(message.error("Exception occurred: {}: {} ({})".format(name, exc_value, exc_type)))
+        print(message.error(f"Exception occurred: {name}: {exc_value} ({exc_type})"))
 
         inform_verbose_and_debug()
 
