@@ -20,7 +20,7 @@ def lock_scheduler():
     if old_config != "on":
         gdb.execute("set scheduler-locking on")
         yield
-        gdb.execute("set scheduler-locking %s" % old_config)
+        gdb.execute(f"set scheduler-locking {old_config}")
     else:
         yield
 
