@@ -22,15 +22,21 @@ def fastbin_index(size: int) -> int:
         return (size >> 3) - 2
 
 
+# TODO: Move these heap constants and macros to elsewhere, because pwndbg/heap/ptmalloc.py also uses them, we are duplicating them here.
 SIZE_SZ = pwndbg.gdblib.arch.ptrsize
 MINSIZE = pwndbg.gdblib.arch.ptrsize * 4
-# i386 will override it to 16.
-# See https://elixir.bootlin.com/glibc/glibc-2.26/source/sysdeps/i386/malloc-alignment.h#L22
-MALLOC_ALIGN = (
-    16
-    if pwndbg.gdblib.arch.current == "i386" and pwndbg.glibc.get_version() >= (2, 26)
-    else pwndbg.gdblib.arch.ptrsize * 2
-)
+if pwndbg.gdblib.arch.current == "i386" and pwndbg.glibc.get_version() >= (2, 26):
+    # i386 will override it to 16 when GLIBC version >= 2.26
+    # See https://elixir.bootlin.com/glibc/glibc-2.26/source/sysdeps/i386/malloc-alignment.h#L22
+    MALLOC_ALIGN = 16
+elif hasattr(gdb.Type, "alignof"):
+    # See https://elixir.bootlin.com/glibc/glibc-2.37/source/sysdeps/generic/malloc-alignment.h#L27
+    long_double_alignment = pwndbg.gdblib.typeinfo.lookup_types("long double").alignof
+    MALLOC_ALIGN = long_double_alignment if 2 * SIZE_SZ < long_double_alignment else 2 * SIZE_SZ
+else:
+    # alignof doesn't available in GDB < 8.2 (https://sourceware.org/git/gitweb.cgi?p=binutils-gdb.git;a=blob_plain;f=gdb/NEWS;hb=gdb-8.2-release)
+    # Hardcoded the MALLOC_ALIGN to 16 for powerpc, and 2 * SIZE_SZ for other archs
+    MALLOC_ALIGN = 16 if pwndbg.gdblib.arch.current == "powerpc" else 2 * SIZE_SZ
 MALLOC_ALIGN_MASK = MALLOC_ALIGN - 1
 MAX_FAST_SIZE = 80 * SIZE_SZ // 4
 NBINS = 128
@@ -93,7 +99,7 @@ class FakeGDBField:
     def __init__(
         self,
         bitpos,
-        name,
+        name: str,
         type,
         parent_type,
         enumval=None,
@@ -147,7 +153,7 @@ class CStruct2GDB:
         """
         output = "{\n"
         for f in self._c_struct._fields_:
-            output += "  %s = %s,\n" % (f[0], self.read_field(f[0]))
+            output += f"  {f[0]} = {self.read_field(f[0])},\n"
         output += "}"
         return output
 
@@ -207,6 +213,13 @@ class CStruct2GDB:
         """
         return self.address + getattr(self._c_struct, field).offset
 
+    @classmethod
+    def get_field_offset(cls, field: str) -> int:
+        """
+        Returns the offset of the specified field.
+        """
+        return getattr(cls._c_struct, field).offset
+
     def items(self) -> tuple:
         """
         Returns a tuple of (field name, field value) pairs.
@@ -691,7 +704,7 @@ class c_malloc_par_2_26(Structure):
         ("sbrk_base", c_pvoid),
         ("tcache_bins", c_size_t),
         ("tcache_max_bytes", c_size_t),
-        ("tcache_count", ctypes.c_int32),
+        ("tcache_count", c_size_t),
         ("tcache_unsorted_limit", c_size_t),
     ]
 
@@ -767,7 +780,7 @@ class c_malloc_par_2_35(Structure):
         ("sbrk_base", c_pvoid),
         ("tcache_bins", c_size_t),
         ("tcache_max_bytes", c_size_t),
-        ("tcache_count", ctypes.c_int32),
+        ("tcache_count", c_size_t),
         ("tcache_unsorted_limit", c_size_t),
     ]
 
