@@ -1,11 +1,10 @@
 import gdb
 
-import pwndbg.elf
-import pwndbg.memoize
+import pwndbg.gdblib.elf
+import pwndbg.lib.cache
 
 
-@pwndbg.memoize.reset_on_start
-@pwndbg.memoize.reset_on_objfile
+@pwndbg.lib.cache.cache_until("start", "objfile")
 def r2pipe():
     """
     Spawn and return a r2pipe handle for the current process file.
@@ -22,12 +21,13 @@ def r2pipe():
     """
     filename = gdb.current_progspace().filename
     if not filename:
-        raise Exception('Could not find objfile to create a r2pipe for')
+        raise Exception("Could not find objfile to create a r2pipe for")
 
     import r2pipe
-    flags = ['-e', 'io.cache=true']
-    if pwndbg.elf.get_elf_info(filename).is_pie and pwndbg.elf.exe():
-        flags.extend(['-B', hex(pwndbg.elf.exe().address)])
+
+    flags = ["-e", "io.cache=true"]
+    if pwndbg.gdblib.elf.get_elf_info(filename).is_pie and pwndbg.gdblib.elf.exe():
+        flags.extend(["-B", hex(pwndbg.gdblib.elf.exe().address)])
     r2 = r2pipe.open(filename, flags=flags)
     r2.cmd("aaaa")
     return r2
