@@ -1,20 +1,18 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
-
 import functools
 import subprocess
 from subprocess import STDOUT
 
+from pwnlib.util.misc import which
+
 import pwndbg.commands
-import pwndbg.which
 
 
 class OnlyWithCommand:
-    def __init__(self, *commands):
+    def __init__(self, *commands) -> None:
         self.all_cmds = list(map(lambda cmd: cmd[0] if isinstance(cmd, list) else cmd, commands))
         for command in commands:
             self.cmd = command if isinstance(command, list) else [command]
-            self.cmd_path = pwndbg.which.which(self.cmd[0])
+            self.cmd_path = which(self.cmd[0])
             if self.cmd_path:
                 break
 
@@ -27,9 +25,10 @@ class OnlyWithCommand:
             if self.cmd_path:
                 return function(*a, **kw)
             else:
-                raise OSError('Could not find command(s) %s in $PATH' % ', '.join(self.all_cmds))
+                raise OSError(f"Could not find command(s) {', '.join(self.all_cmds)} in $PATH")
+
         return _OnlyWithCommand
 
 
 def call_cmd(cmd):
-    return subprocess.check_output(cmd, stderr=STDOUT).decode('utf-8')
+    return subprocess.check_output(cmd, stderr=STDOUT).decode("utf-8")
